import yaml

from collections import OrderedDict

def init_yaml():
  def represent_none(self, _):
      return self.represent_scalar("tag:yaml.org,2002:null", "")

  yaml.add_representer(type(None), represent_none)

def ordered_load(stream, Loader=yaml.Loader, object_pairs_hook=OrderedDict):
  class OrderedLoader(Loader):
    pass

  def construct_mapping(loader, node):
    loader.flatten_mapping(node)
    return object_pairs_hook(loader.construct_pairs(node))

  OrderedLoader.add_constructor(
    yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG,
    construct_mapping)

  return yaml.load(stream, OrderedLoader)

def ordered_dump(data, stream=None, Dumper=yaml.Dumper, **kwds):
  class OrderedDumper(Dumper):
    pass

  def _dict_representer(dumper, data):
    return dumper.represent_mapping(
      yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG,
      data.items())
      
  OrderedDumper.add_representer(OrderedDict, _dict_representer)

  return yaml.dump(data, stream, OrderedDumper, **kwds)